=======
History
=======

0.1.0 (2021-10-05)
------------------

* This is the first release!
* Create the package
* Add CDEC functionality
* Add SNOTEL functionality
* Add CLI to find stations from shapefile
* Write a custom Snotel client using zeep

0.2.0 (2021-12-29)
------------------

* Added mesowest network
* Added in a token json arg to the get_*_data functions
* Pinned docutils for an update that happened
* Added in a resample_df function for the highway stations where the returned data is 5min for air temp.

0.3.0 (2022-10-28)
------------------

* Added USGS network
